require 'rubygems'
require 'promotion/config'
require 'promotion/enforcer'
require 'promotion/generator'
require 'promotion/evolver'
require 'logger'
require 'time'

module Promotion	# :nodoc:

# The Promotion::Application coordinates the activity of the components:
# - Enforcer
# - Generator
# - Evolver
class Application

	# Creates a new Promotion::Application instance for a specific app to be promoted.
	# A global +$log+ logger is also created.
	def initialize(appname)
		@appname = appname
		$log = Logger.new(Files::Log, 0) # rotate log file at 1M limit
		$log.formatter = proc { |severity, datetime, progname, message|
      "#{datetime.iso8601()} #{severity} #{message}\n"
    }
		$log.level = Logger::INFO
	end

	# Promotes an application into production.
	def promote()
		enforcer = Promotion::Enforcer.new(@appname)
		enforcer.start()
		Generator::start()
		$log.info("Application #{@appname} successfully promoted.")
	end

	# Evolves the database to a target version, or as far as possible, by
	# executing database migration scripts in the +evolve+ folder
	def evolve(target=nil)
		evolver = Promotion::Evolver.new(@appname, true, target)
		evolver.start()
	end

	# Devolve a database back to an earlier version
	def devolve(target=nil)
		evolver = Promotion::Evolver.new(@appname, false, target)
		evolver.start()
	end

end
end
